pub struct ContractObj<A>(/* private fields */)
where
A: VMApi;Trait Implementations
impl<A> AutoImpl for ContractObj<A>where
A: VMApi,
Sourceimpl<A> CallableContract for ContractObj<A>
impl<A> CallableContract for ContractObj<A>
Sourceimpl<A> ContractBase for ContractObj<A>where
A: VMApi,
impl<A> ContractBase for ContractObj<A>where
A: VMApi,
type Api = A
Sourcefn call_value(&self) -> CallValueWrapper<Self::Api>
fn call_value(&self) -> CallValueWrapper<Self::Api>
Gateway into the call value retrieval functionality.
The payment annotations should normally be the ones to handle this,
but the developer is also given direct access to the API.
Sourcefn send(&self) -> SendWrapper<Self::Api>
fn send(&self) -> SendWrapper<Self::Api>
Gateway to the functionality related to sending transactions from the current contract.
Sourcefn tx(&self) -> Tx<TxScEnv<Self::Api>, (), (), (), (), (), ()>
fn tx(&self) -> Tx<TxScEnv<Self::Api>, (), (), (), (), (), ()>
Starts the declaration of a new transaction.
Sourcefn send_raw(&self) -> SendRawWrapper<Self::Api>
fn send_raw(&self) -> SendRawWrapper<Self::Api>
Low-level functionality related to sending transactions from the current contract. Read more
Sourcefn blockchain(&self) -> BlockchainWrapper<Self::Api>
fn blockchain(&self) -> BlockchainWrapper<Self::Api>
Gateway blockchain info related to the current transaction and to accounts.
Sourcefn crypto(&self) -> CryptoWrapper<Self::Api>
fn crypto(&self) -> CryptoWrapper<Self::Api>
Stateless crypto functions provided by the Arwen VM.
Sourcefn serializer(&self) -> ManagedSerializer<Self::Api>
fn serializer(&self) -> ManagedSerializer<Self::Api>
Component that provides contract developers access
to highly optimized manual serialization and deserialization.
fn error(&self) -> ErrorHelper<Self::Api>
fn storage_raw(&self) -> StorageRawWrapper<Self::Api>
Sourceimpl<A> EndpointWrappers for ContractObj<A>where
A: VMApi,
impl<A> EndpointWrappers for ContractObj<A>where
A: VMApi,
fn call_set_feature_flag_endpoint(&mut self)
fn call(&mut self, fn_name: &str) -> bool
fn callback_selector( &mut self, ___cb_closure___: &CallbackClosureForDeser<Self::Api>, ) -> CallbackSelectorResult
fn callback(&mut self)